@@ -50,7 +50,7 @@ dir.move <- function(from, to){
   }
   stopifnot(dir.create(to, recursive=TRUE));
   setwd(from)
-  if(all(file.copy(list.files(all.files=TRUE, include.dirs=TRUE), to, recursive=TRUE))){
+  if(all(file.copy(list.files(include.dirs=TRUE), to, recursive=TRUE))){
     #success!
     unlink(from, recursive=TRUE);
     return(TRUE)
@@ -158,7 +158,7 @@ stop <- function(..., call. = FALSE, domain = NULL){
 stub <- function(){
   curl::curl_fetch_memory()
   pander::pander()
-  devtools::install_github()
+  remotes::install_github()
   brew::brew()
   httpuv::runServer()
   knitr::knit()
